@@ -22,7 +22,7 @@ void UmlAttribute::memo_ref() {
 void UmlAttribute::html(QCString, unsigned int, unsigned int) {
   define();
 
-  fw.write("<table><tr><td><div class=\"element\">Attribut <b>");
+  fw.write("<table><tr><td><div class=\"element\">Attribute <b>");
   writeq(name());
   fw.write("</b></div></td></tr></table>\n");
 
