@@ -38,18 +38,11 @@ void UmlComponent::write(FileOut & out) {
 void UmlComponent::write(FileOut & out, const QVector< UmlClass > & v, const char * k1, const char * k2) {
   unsigned n = v.size();
   unsigned index;
-  char s[64];
-  
-  strcpy(s, k2);
-  
-  char * p = s + strlen(s);
   
   for (index = 0; index != n; index += 1) {
-    sprintf(p, "%u_", index);
-    
     out.indent();
     out << "<" << k1;
-    out.id_prefix(this, s);
+    out.id_prefix(this, k2, index);
     
     UmlClass * cl = v[index];
     
