@@ -169,12 +169,8 @@ void UmlItem::write_default_value(FileOut & out, QCString v, UmlItem * who, int
     out << "<defaultValue xmi:type=\"uml:LiteralString\"";
     if (rank == -1)
       out.id_prefix(who, "VALUE_");
-    else {
-      char s[32];
-      
-      sprintf(s, "VALUE%d_", rank);
-      out.id_prefix(who, s);
-    }
+    else
+      out.id_prefix(who, "VALUE", rank);
     out << " value=\"";
     out.quote(v);
     out << "\"/>\n";
