@@ -7,12 +7,10 @@
 #include "UmlUseCase.h"
 #include "UmlUseCaseReference.h"
 void UmlUseCaseAssociation::write(FileOut & out, UmlItem * d, int rank, const char * k) {
-  char s[16];
   
   out.indent();
   out << '<' << k << " xmi:type=\"uml:Association\"";
-  sprintf(s, "UCAC%d_", rank);
-  out.id_prefix(d, s);
+  out.id_prefix(d, "UCAC", rank);
   if (! name().isEmpty()){
     out << " name=\"";
     out.quote(name());
@@ -24,18 +22,16 @@ void UmlUseCaseAssociation::write(FileOut & out, UmlItem * d, int rank, const ch
   
   out.indent();
   out << "<ownedEnd xmi:type=\"uml:Property\"";
-  out.id_prefix(d, s + 2);
+  out.id_prefix(d, "AC", rank);
   out.ref(actor(), "type");
-  out.ref(d, "association", s);
+  out.ref(d, "association", "UCAC", rank);
   out << "/>\n";
   
   out.indent();
   out << "<ownedEnd xmi:type=\"uml:Property\"";
-  s[2] = 'U';
-  out.id_prefix(d, s + 2);
-  s[2] = 'A';
+  out.id_prefix(d, "UC", rank);
   out.ref(useCase()->useCase(), "type");
-  out.ref(d, "association", s);
+  out.ref(d, "association", "UCAC", rank);
   out << "/>\n";
 
   out.indent(-1);
