@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -405,10 +405,10 @@ bool Class::manage_implements(ClassContainer * container, aRelationKind k,
 bool Class::add_inherit(aRelationKind k, UmlTypeSpec & typespec,
 			QValueList<UmlTypeSpec> & actuals, 
 			QCString & str_actuals) {
-  unsigned actual_rank;
-  
-  if (typespec.explicit_type.isEmpty() && !actuals.isEmpty())
-    actual_rank = uml->actuals().count();
+  unsigned actual_rank = 
+    (typespec.explicit_type.isEmpty() && !actuals.isEmpty())
+      ? uml->actuals().count()
+      : 0;
     
   UmlRelation * rel =
     UmlRelation::create((actuals.isEmpty()) ? k : aRealization,
@@ -575,7 +575,17 @@ bool Class::get_formals(FormalParameterList & tmplt, bool name_only,
 }
 
 bool Class::manage_member(QCString s, QCString & path) {
-  aVisibility visibility = PackageVisibility;
+  aVisibility visibility;
+  
+  switch (stereotype) {
+  case 'i':
+  case '@':
+    visibility = PublicVisibility;
+    break;
+  default:
+    visibility = PackageVisibility;
+  }
+
   QCString comment = Lex::get_comments();
   QCString description = Lex::get_description();
   bool m_staticp = FALSE;
@@ -675,7 +685,12 @@ bool Class::manage_member(QCString s, QCString & path) {
   }
   
   for (;;) {
-    if (s == "(") {
+    if (s.isEmpty()) {
+      if (!Package::scanning())
+	Lex::premature_eof();
+      return FALSE;
+    }
+    else if (s == "(") {
       // an operation
       if (Package::scanning()) {
 	UmlOperation::skip_body(0);
@@ -742,7 +757,12 @@ bool Class::manage_member(QCString s, QCString & path) {
 	return FALSE;
       }
       
-      if (type.type != 0) {
+      // in case of a generic and at least an actual is a known class
+      // force the use of a operation to the actual stereotyped by the
+      // generic, typically for List ...
+      if ((type.type != 0) &&
+	  ((first_actual_class == 0) ||
+	   JavaSettings::umlType(genericname).isEmpty())) {
 	if (!UmlRelation::new_one(this, name, type, str_actuals, visibility,
 				  m_staticp, m_finalp, m_transientp, m_volatilep,
 				  array, value, comment, description, annotation))
