@@ -242,8 +242,17 @@ UmlArtifact * UmlArtifact::generated_one()
   return current;
 }
 
+void UmlArtifact::imported(QCString s) {
+  if (!JavaSettings::isForcePackagePrefixGeneration()) {
+    if (imports == 0)
+      // init it
+      (void) is_imported("", "");
+    
+    imports->insert(s, this);
+  }
+}
 
-bool UmlArtifact::imported(QCString pack_name, QCString class_name) {
+bool UmlArtifact::is_imported(QCString pack_name, QCString class_name) {
   if (imports == 0) {
     imports = new QAsciiDict<UmlArtifact>(17);
     
