@@ -53,7 +53,8 @@ class UmlArtifact : public UmlBaseArtifact {
     
     virtual void generate();
     
-    bool imported(QCString pack_name, QCString class_name);
+    void imported(QCString s);
+    bool is_imported(QCString pack_name, QCString class_name);
     
     static UmlArtifact * generated_one();
     static UmlPackage * generation_package();
