@@ -293,7 +293,8 @@ void UmlClass::write(QTextOStream & f) {
 	QCString s = pack->javaPackage();
 	
 	if (!s.isEmpty() && (s != "java.lang") && (s.left(10) != "java.lang.") &&
-	    !UmlArtifact::generated_one()->imported(s, name()))
+	    (JavaSettings::isForcePackagePrefixGeneration() ||
+	     !UmlArtifact::generated_one()->is_imported(s, name())))
 	  f << s << '.';
       }
     }
@@ -304,20 +305,24 @@ void UmlClass::write(QTextOStream & f) {
 void UmlClass::import(QTextOStream & f, const QCString & indent) {
   if (parent()->kind() == aClass)
     ((UmlClass *) parent())->import(f, indent);
-  else if (!isJavaExternal()) {
-    UmlArtifact * cp = associatedArtifact();
-    UmlPackage * pack = (UmlPackage *)
-      ((cp != 0) ? (UmlItem *) cp : (UmlItem *) this)->package();
-    QCString s = pack->javaPackage();
-    
-    if (!s.isEmpty())
-      f << indent << "import " << s << '.' << name() << ";\n";
-  }
   else {
-    QCString s = package()->javaPackage();
+    QCString s;
     
-    if (!s.isEmpty())
-      f << indent << "import " << s << '.' << name() << ";\n";
+    if (!isJavaExternal()) {
+      UmlArtifact * cp = associatedArtifact();
+      UmlPackage * pack = (UmlPackage *)
+	((cp != 0) ? (UmlItem *) cp : (UmlItem *) this)->package();
+      
+      s = pack->javaPackage();
+    }
+    else
+      s = package()->javaPackage();
+    
+    if (!s.isEmpty()) {
+      s += "." + name();
+      f << indent << "import " << s << ";\n";
+      UmlArtifact::generated_one()->imported(s);
+    }
   }
 }
 
