@@ -29,6 +29,7 @@
 #include "UmlPackage.h"
 #include "UmlCom.h"
 #include "JavaSettings.h"
+#include "UmlArtifact.h"
 
 UmlPackage::UmlPackage(void * id, const QCString & n)
     : UmlBasePackage(id, n) {
@@ -132,6 +133,8 @@ UmlPackage * UmlPackage::package() {
 void UmlPackage::import(QTextOStream & f, const QCString & indent) {
   QCString s = javaPackage();
   
-  if (!s.isEmpty())
+  if (!s.isEmpty()) {
     f << indent << "import " << s << ".*;\n";
+    UmlArtifact::generated_one()->imported(s);
+  }
 }
