@@ -397,7 +397,10 @@ enum JavaSettingsCmd {
   setJavaEnumItemDeclCmd,
   
   // api 30
-  setJavaJavadocStyleCmd
+  setJavaJavadocStyleCmd,
+    
+  // api 40
+  setJavaForcePackageGenCmd
 };
 
 // api 34
