@@ -98,7 +98,7 @@ void BrowserActivityObject::update_idmax_for_root()
   all.update_idmax_for_root();
 }
     
-void BrowserActivityObject::referenced_by(QList<BrowserNode> & l, bool ondelete) {
+void BrowserActivityObject::referenced_by(QList<BrowserNode> & l, bool) {
   BrowserFlow::compute_referenced_by(l, this);
   BrowserSimpleRelation::compute_referenced_by(l, this);
 }
