@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -69,6 +69,7 @@ class BrowserComponentView : public BrowserNode, public Labeled<BrowserComponent
     virtual void open(bool);
     virtual UmlCode get_type() const;
     virtual int get_identifier() const;
+    virtual const char * help_topic() const;
     virtual bool may_contains_them(const QList<BrowserNode> &,
 				   bool & duplicable) const;
     virtual BasicData * get_data() const;
@@ -78,6 +79,7 @@ class BrowserComponentView : public BrowserNode, public Labeled<BrowserComponent
     virtual UmlColor get_color(UmlCode) const;
     virtual bool get_shadow(UmlCode) const;
     virtual bool get_draw_all_relations(UmlCode) const;
+    virtual bool get_show_stereotype_properties(UmlCode k) const;
     virtual bool get_auto_label_position(UmlCode who) const;
     virtual void save(QTextStream &, bool ref, QString & warning);
         
