@@ -116,8 +116,8 @@ BrowserPackage::BrowserPackage(QString s, BrowserView * parent, int id)
   classdiagram_settings.shadow = UmlYes;
   classdiagram_settings.show_stereotype_properties = UmlNo;
     
-  class_settings.attribute_visibility = UmlProtected;
-  class_settings.relation_visibility = UmlProtected;
+  class_settings.attribute_visibility = UmlPrivate;
+  class_settings.relation_visibility = UmlPrivate;
   class_settings.operation_visibility = UmlPublic;
     
   usecasediagram_settings.package_name_in_tab = UmlNo;
