@@ -197,7 +197,7 @@ void BrowserRelation::referenced_by(QList<BrowserNode> & l, bool ondelete) {
 }
 
 BrowserRelation * BrowserRelation::temporary(RelationData * d) {
-  BrowserRelation * result = new BrowserRelation(0);
+  BrowserRelation * result = new BrowserRelation(-1);
   
   result->def = d;
   return result;
