@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -73,6 +73,7 @@ class BrowserStateDiagram : public BrowserDiagram {
     virtual void read_session(char * & st);
     virtual UmlCode get_type() const;
     virtual int get_identifier() const;
+    virtual const char * help_topic() const;
     virtual BasicData * get_data() const;
     virtual void set_name(const char * s);
     virtual void get_statediagramsettings(StateDiagramSettings &) const;
@@ -81,6 +82,7 @@ class BrowserStateDiagram : public BrowserDiagram {
     virtual bool get_shadow() const;
     virtual bool get_draw_all_relations() const;
     virtual void dont_draw_all_relations();
+    virtual bool get_show_stereotype_properties(UmlCode k) const;
     virtual UmlColor get_color(UmlCode) const;
     virtual void package_settings(bool & name_in_tab, ShowContextMode & show_context) const;
     virtual bool get_write_label_horizontally(UmlCode who) const ;
