@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -77,9 +77,10 @@ class BasicData : public QObject {
     static void resignal_deleted();
         
     const char * get_stereotype() const { return stereotype; };
-    virtual void set_stereotype(const QString &);
-    virtual void set_stereotype(const QCString &);
-    virtual void set_stereotype(const char *);
+    const char * get_short_stereotype() const;
+    virtual bool set_stereotype(const QString &);
+    virtual bool set_stereotype(const QCString &);
+    virtual bool set_stereotype(const char *);
     
     virtual void set_browser_node(BrowserNode * bn);
     BrowserNode * get_browser_node() const { return browser_node; };
@@ -100,6 +101,7 @@ class BasicData : public QObject {
     virtual void send_cpp_def(ToolCom * com);
     virtual void send_java_def(ToolCom * com);
     virtual void send_php_def(ToolCom * com);
+    virtual void send_python_def(ToolCom * com);
     virtual void send_idl_def(ToolCom * com);
     
   protected slots:
