@@ -263,7 +263,12 @@ void ClassInstanceData::check_rels() {
 	? rd->get_end_class() : rd->get_start_class();
       BrowserClass * cl = ((ClassInstanceData *) d)->get_class();
       
-      if (cl != other) {
+      if (cl == 0) {
+	// instance doesn't exist
+	// note : its brower_node will be deleted
+	remove = TRUE;
+      }
+      else if (cl != other) {
 	QList<BrowserClass> l;
 	
 	cl->get_all_parents(l);
@@ -703,7 +708,7 @@ void ClassInstanceData::save(QTextStream & st, QString & warning) const {
   while (it_rel != relations.end()) {
     const SlotRel & slot_rel = *it_rel;
     
-    if (slot_rel.is_a) {
+    if (slot_rel.is_a && !slot_rel.value->deletedp()) {
       // to not have unconsistency on load,
       // other side remade at load time
       nl_indent(st);
