@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qpopupmenu.h> 
 #include <qcursor.h>
@@ -70,6 +70,7 @@ ActivityActionCanvas::ActivityActionCanvas(BrowserNode * bn, UmlCanvas * canvas,
   check_pins();
   check_parametersets();
   check_conditions();
+  check_stereotypeproperties();
 
   connect(bn->get_data(), SIGNAL(changed()), this, SLOT(modified()));
   connect(bn->get_data(), SIGNAL(deleted()), this, SLOT(deleted()));
@@ -160,8 +161,8 @@ void ActivityActionCanvas::update() {
   s = s.stripWhiteSpace();
   
   align = (s.find('\n') != -1)
-    ? (int) QObject::AlignLeft | QObject::AlignVCenter
-    : (int) QObject::AlignCenter | QObject::WordBreak;
+    ? (int) ::Qt::AlignLeft | ::Qt::AlignVCenter
+    : (int) ::Qt::AlignCenter | ::Qt::WordBreak;
   
   force_pins_arround();
   check_parameter_sets_position();
@@ -250,6 +251,7 @@ void ActivityActionCanvas::modified() {
     draw_all_simple_relations();
   }
   check_conditions();
+  check_stereotypeproperties();
   canvas()->update();
   package_modified();
 }
@@ -460,8 +462,8 @@ void ActivityActionCanvas::draw(QPainter & p) {
   QColor bckgrnd = p.backgroundColor();
   
   p.setBackgroundMode((used_color == UmlTransparent)
-		      ? QObject::TransparentMode
-		      : QObject::OpaqueMode);
+		      ? ::Qt::TransparentMode
+		      : ::Qt::OpaqueMode);
 
   QColor co = color(used_color);
   
@@ -484,8 +486,8 @@ void ActivityActionCanvas::draw(QPainter & p) {
       
       int t = (r.y() + r.bottom() - margin)/2;
       
-      p.setPen(QObject::SolidLine);
-      p.setBackgroundMode(QObject::TransparentMode);
+      p.setPen(::Qt::SolidLine);
+      p.setBackgroundMode(::Qt::TransparentMode);
       p.drawLine(r.right() - margin, t, r.right() - 1, t);
       p.lineTo(r.right() - margin - 1, t + margin);
       p.lineTo(r.right() - 1, t + margin);
@@ -542,10 +544,10 @@ void ActivityActionCanvas::draw(QPainter & p) {
 	  b.setPoint(3, r.x() + shadow, r.bottom() + shadow);
 	  b.setPoint(4, r.x() + margin + shadow, (r.y() + r.bottom())/2 + shadow);
 	  b.setPoint(5, r.x() + shadow, r.y() + shadow);
-	  p.setBrush(QObject::darkGray);
-	  p.setPen(QObject::NoPen);
+	  p.setBrush(::Qt::darkGray);
+	  p.setPen(::Qt::NoPen);
 	  p.drawPolygon(b, TRUE, 0, 5);
-	  p.setPen(QObject::SolidLine);
+	  p.setPen(::Qt::SolidLine);
 
 	  if (fp != 0)
 	    draw_shadow(fp, b);
@@ -595,10 +597,10 @@ void ActivityActionCanvas::draw(QPainter & p) {
 	  b.setPoint(3, r.right() - margin + shadow, r.bottom() + shadow);
 	  b.setPoint(4, r.x() + shadow, r.bottom() + shadow);
 	  b.setPoint(5, r.x() + shadow, r.y() + shadow);
-	  p.setBrush(QObject::darkGray);
-	  p.setPen(QObject::NoPen);
+	  p.setBrush(::Qt::darkGray);
+	  p.setPen(::Qt::NoPen);
 	  p.drawPolygon(b, TRUE, 0, 5);
-	  p.setPen(QObject::SolidLine);
+	  p.setPen(::Qt::SolidLine);
 
 	  if (fp != 0)
 	    draw_shadow(fp, b);
@@ -620,17 +622,17 @@ void ActivityActionCanvas::draw(QPainter & p) {
     if ((used_color != UmlTransparent) && (shadow != 0)) {
       r.setRight(r.right() - shadow);
       r.setBottom(r.bottom() - shadow);
-      p.setPen(QObject::NoPen);
-      p.setBrush(QObject::darkGray);
+      p.setPen(::Qt::NoPen);
+      p.setBrush(::Qt::darkGray);
       p.drawRoundRect(r.left() + shadow, r.top() + shadow, r.width(), r.height());
       
       if (fp != 0)
 	fprintf(fp, "\t<rect fill=\"#%06x\" stroke=\"none\" stroke-opacity=\"1\""
 		" x=\"%d\" y=\"%d\" width=\"%d\" height=\"%d\" rx=\"10\" />\n",
-		QObject::darkGray.rgb()&0xffffff,
+		::Qt::darkGray.rgb()&0xffffff,
 		r.left() + shadow, r.top() + shadow, r.width() - 1, r.height() - 1);
 
-      p.setPen(QObject::SolidLine);
+      p.setPen(::Qt::SolidLine);
     }
     
     p.setBrush(co);
@@ -747,6 +749,8 @@ void ActivityActionCanvas::menu(const QPoint&) {
   }
   m.insertItem("Upper", 0);
   m.insertItem("Lower", 1);
+  m.insertItem("Go up", 13);
+  m.insertItem("Go down", 14);
   m.insertSeparator();
   m.insertItem("Edit drawing settings", 2);
   m.insertSeparator();
@@ -797,6 +801,14 @@ void ActivityActionCanvas::menu(const QPoint&) {
     lower();
     modified();	// call package_modified()
     return;
+  case 13:
+    z_up();
+    modified();	// call package_modified()
+    return;
+  case 14:
+    z_down();
+    modified();	// call package_modified()
+    return;
   case 2:
     edit_drawing_settings();
     return;
@@ -852,6 +864,10 @@ void ActivityActionCanvas::apply_shortcut(QString s) {
     upper();
   else if (s == "Lower")
     lower();
+  else if (s == "Go up")
+    z_up();
+  else if (s == "Go down")
+    z_down();
   else if (s == "Edit drawing settings") {
     edit_drawing_settings();
     return;
@@ -915,6 +931,17 @@ void ActivityActionCanvas::edit_drawing_settings(QList<DiagramItem> & l) {
   }
 }
 
+bool ActivityActionCanvas::get_show_stereotype_properties() const {
+  switch (settings.show_stereotype_properties) {
+  case UmlYes:
+    return TRUE;
+  case UmlNo:
+    return FALSE;
+  default:
+    return the_canvas()->browser_diagram()->get_show_stereotype_properties(UmlCodeSup);
+  }
+}
+
 const char * ActivityActionCanvas::may_start(UmlCode & l) const {
   return (l == UmlFlow)
     ? ((BrowserActivityAction *) browser_node)->may_start()
@@ -1005,6 +1032,8 @@ void ActivityActionCanvas::save(QTextStream & st, bool ref, QString & warning) c
       st << "post ";
       post->save(st, FALSE, warning);
     }
+    
+    save_stereotype_property(st, warning);
 
     indent(-1);
     nl_indent(st);
@@ -1071,12 +1100,15 @@ ActivityActionCanvas * ActivityActionCanvas::read(char * & st, UmlCanvas * canva
       k = read_keyword(st);
     }
 
+    result->read_stereotype_property(st, k);	// updates k
+    
     if (strcmp(k, "end"))
       wrong_keyword(k, "end");
 
     result->check_pins();
     result->check_parametersets();
     result->check_conditions();
+    result->check_stereotypeproperties();
     
     if (canvas->paste())
       result->remove_if_already_present();
