@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qpopupmenu.h> 
 #include <qcursor.h>
@@ -50,6 +50,7 @@ ActivityNodeCanvas::ActivityNodeCanvas(BrowserNode * bn, UmlCanvas * canvas,
     : DiagramCanvas(0, canvas, x, y, 16, 16, 0), horiz(FALSE) {
   browser_node = bn;
   set_xpm();
+  check_stereotypeproperties();
    
   connect(bn->get_data(), SIGNAL(changed()), this, SLOT(modified()));
   connect(bn->get_data(), SIGNAL(deleted()), this, SLOT(deleted()));
@@ -164,6 +165,7 @@ void ActivityNodeCanvas::modified() {
   show();
   update_show_lines();
   force_self_rel_visible();
+  check_stereotypeproperties();
   if (the_canvas()->must_draw_all_relations())
     draw_all_flows();
   canvas()->update();
@@ -183,7 +185,7 @@ void ActivityNodeCanvas::draw(QPainter & p) {
 
   QRect r = rect();
   
-  p.setBackgroundMode(QObject::OpaqueMode);
+  p.setBackgroundMode(::Qt::OpaqueMode);
   
   p.drawPixmap(r.topLeft(), *xpm);
     
@@ -320,6 +322,8 @@ void ActivityNodeCanvas::menu(const QPoint&) {
   m.insertSeparator();
   m.insertItem("Upper", 0);
   m.insertItem("Lower", 1);
+  m.insertItem("Go up", 13);
+  m.insertItem("Go down", 14);
   m.insertSeparator();
   switch (browser_node->get_type()) {
   case ForkAN:
@@ -345,7 +349,7 @@ void ActivityNodeCanvas::menu(const QPoint&) {
   if (browser_node->is_writable())
     m.insertItem("Delete from model", 8);
   m.insertSeparator();
-  if (Tool::menu_insert(&toolm, browser_node->get_type(), 10))
+  if (Tool::menu_insert(&toolm, browser_node->get_type(), 20))
     m.insertItem("Tool", &toolm);
   
   switch (index = m.exec(QCursor::pos())) {
@@ -357,6 +361,14 @@ void ActivityNodeCanvas::menu(const QPoint&) {
     lower();
     modified();	// call package_modified()
     return;
+  case 13:
+    z_up();
+    modified();	// call package_modified()
+    return;
+  case 14:
+    z_down();
+    modified();	// call package_modified()
+    return;
   case 2:
     horiz ^= TRUE;
     set_xpm();
@@ -381,8 +393,8 @@ void ActivityNodeCanvas::menu(const QPoint&) {
     browser_node->delete_it();	// will delete the canvas
     break;
   default:
-    if (index >= 10)
-      ToolCom::run(Tool::command(index - 10), browser_node);
+    if (index >= 20)
+      ToolCom::run(Tool::command(index - 20), browser_node);
     return;
   }
   
@@ -398,6 +410,10 @@ void ActivityNodeCanvas::apply_shortcut(QString s) {
     upper();
   else if (s == "Lower")
     lower();
+  else if (s == "Go up")
+    z_up();
+  else if (s == "Go down")
+    z_down();
   else {
     browser_node->apply_shortcut(s);
     return;
@@ -454,7 +470,10 @@ void ActivityNodeCanvas::save(QTextStream & st, bool ref, QString & warning) con
     if (horiz)
       st << "horizontal ";
     save_xyz(st, this, "xyz");
+    save_stereotype_property(st, warning);
     indent(-1);
+    nl_indent(st);
+    st << "end";
   }
 }
 
@@ -492,9 +511,19 @@ ActivityNodeCanvas * ActivityNodeCanvas::read(char * & st, UmlCanvas * canvas,
       wrong_keyword(k, "xyz");
     
     read_xyz(st, result);
+
+    if (read_file_format() >= 58) {
+      k = read_keyword(st);
+      result->read_stereotype_property(st, k);	// updates k
+      
+      if (strcmp(k, "end"))
+	wrong_keyword(k, "end");
+    }
+    
     result->set_xpm();
     result->set_center100();
     result->show();
+    result->check_stereotypeproperties();
     
     if (canvas->paste())
       result->remove_if_already_present();
