@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -26,9 +26,9 @@
 #ifndef CDCLASSCANVAS_H
 #define CDCLASSCANVAS_H
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qobject.h>
 
@@ -36,8 +36,6 @@
 #include "MultipleDependency.h"
 #include "Settings.h"
 
-#define CLASS_CANVAS_MIN_SIZE 40
-
 class TemplateCanvas;
 class RelationData;
 class ConstraintCanvas;
@@ -100,9 +98,10 @@ class CdClassCanvas : public QObject, public DiagramCanvas,
     
     virtual bool has_drawing_settings() const;
     virtual void edit_drawing_settings(QList<DiagramItem> &);
+    void edit_drawing_settings();
+    virtual bool get_show_stereotype_properties() const;
     
     virtual void apply_shortcut(QString s);
-    void edit_drawing_settings();
   
     virtual void save(QTextStream  & st, bool ref, QString & warning) const;
     static CdClassCanvas * read(char * &, UmlCanvas *, char *);
