@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qfont.h>
 #include <qpopupmenu.h> 
@@ -56,7 +56,7 @@
 
 ColDiagramView::ColDiagramView(QWidget * parent, UmlCanvas * canvas, int id)
     : DiagramView(parent, canvas, id) {
-  load("Collaboration");
+  load("Communication");
   update_msgs();
 }
 
@@ -92,9 +92,12 @@ void ColDiagramView::update_msg_supports() {
 void ColDiagramView::menu(const QPoint&) {
   QPopupMenu m(0);
   
-  m.insertItem(new MenuTitle("Collaboration diagram menu", m.font()), -1);
-  m.insertSeparator();
-  m.insertItem("Edit all the messages", 29);
+  m.insertItem(new MenuTitle("Communication diagram menu", m.font()), -1);
+  
+  if ((((UmlCanvas *) canvas())->browser_diagram())->is_writable()) {
+    m.insertSeparator();
+    m.insertItem("Edit all the messages", 29);
+  }
  
   switch (default_menu(m, 30)) {
   case EDIT_DRAWING_SETTING_CMD:
@@ -104,7 +107,7 @@ void ColDiagramView::menu(const QPoint&) {
     // pure drawing modifications are lost
     // mark the diagram modified because the undid modifications
     // may be saved in the file are not saved in memory
-    load("Collaboration");
+    load("Communication");
     update_msgs();
     window()->package_modified();
     break;
@@ -116,7 +119,7 @@ void ColDiagramView::menu(const QPoint&) {
   
 void ColDiagramView::contentsMousePressEvent(QMouseEvent * e) {
   if (!window()->frozen()) {
-    if (e->button() == QObject::RightButton)
+    if (e->button() == ::Qt::RightButton)
       DiagramView::contentsMousePressEvent(e);
     else {
       UmlCode c = window()->buttonOn();
@@ -203,6 +206,8 @@ void ColDiagramView::contentsMousePressEvent(QMouseEvent * e) {
       }
     }
   }
+  else
+    DiagramView::contentsMousePressEvent(e);
 }
 
 void ColDiagramView::dragEnterEvent(QDragEnterEvent * e) {
