@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <math.h>
 
@@ -60,6 +60,7 @@ ParameterSetCanvas::ParameterSetCanvas(BrowserNode * bn, UmlCanvas * canvas,
     // not on read
     update();
     setZ(a->z());  // note : pins have z+2 to be upper the parameter sets with their lines
+    check_stereotypeproperties();
   }
   
   connect(bn->get_data(), SIGNAL(changed()), this, SLOT(modified()));
@@ -205,6 +206,10 @@ void ParameterSetCanvas::do_moveBy(double, double) {
   // action and pins already in position, can check
   check_position();
 }
+    
+bool ParameterSetCanvas::primaryItem() const {
+  return FALSE;
+}
 
 void ParameterSetCanvas::draw(QPainter & p) {
   if (! visible()) return;
@@ -213,8 +218,8 @@ void ParameterSetCanvas::draw(QPainter & p) {
   QColor bckgrnd = p.backgroundColor();
   
   p.setBackgroundMode((used_color == UmlTransparent)
-		      ? QObject::TransparentMode
-		      : QObject::OpaqueMode);
+		      ? ::Qt::TransparentMode
+		      : ::Qt::OpaqueMode);
 
   QColor co = color(used_color);
   QRect r = rect();
@@ -264,6 +269,8 @@ void ParameterSetCanvas::menu(const QPoint &) {
   m.insertSeparator();
   m.insertItem("Upper", 0);
   m.insertItem("Lower", 1);
+  m.insertItem("Go up", 13);
+  m.insertItem("Go down", 14);
   m.insertSeparator();
   m.insertItem("Edit drawing settings", 2);
   m.insertSeparator();
@@ -277,7 +284,7 @@ void ParameterSetCanvas::menu(const QPoint &) {
     m.insertItem("Delete from model", 8);
     m.insertSeparator();
   }
-  if (Tool::menu_insert(&toolm, UmlParameterSet, 10))
+  if (Tool::menu_insert(&toolm, UmlParameterSet, 20))
     m.insertItem("Tool", &toolm);
   
   switch (index = m.exec(QCursor::pos())) {
@@ -289,6 +296,14 @@ void ParameterSetCanvas::menu(const QPoint &) {
     act->lower();
     modified();	// call package_modified()
     return;
+  case 13:
+    act->z_up();
+    modified();	// call package_modified()
+    return;
+  case 14:
+    act->z_down();
+    modified();	// call package_modified()
+    return;
   case 2:
     edit_drawing_settings();
     return;
@@ -307,8 +322,8 @@ void ParameterSetCanvas::menu(const QPoint &) {
     browser_node->delete_it();	// will delete the canvas
     break;
   default:
-    if (index >= 10)
-      ToolCom::run(Tool::command(index - 10), browser_node);
+    if (index >= 20)
+      ToolCom::run(Tool::command(index - 20), browser_node);
     return;
   }
   
@@ -321,9 +336,13 @@ void ParameterSetCanvas::apply_shortcut(QString s) {
     return;
   }
   else if (s == "Upper")
-    upper();
+    act->upper();
   else if (s == "Lower")
-    lower();
+    act->lower();
+  else if (s == "Go up")
+    act->z_up();
+  else if (s == "Go down")
+    act->z_down();
   else if (s == "Edit drawing settings") {
     edit_drawing_settings();
     return;
@@ -384,6 +403,7 @@ void ParameterSetCanvas::modified() {
   hide();
   update();
   show();
+  check_stereotypeproperties();
   canvas()->update();
   package_modified();
 }
@@ -406,6 +426,7 @@ void ParameterSetCanvas::save(QTextStream & st, bool ref, QString & warning) con
     if (itscolor != UmlDefaultColor)
       st << "  color " << stringify(itscolor);
     save_xyz(st, this, "  xyz");
+    save_stereotype_property(st, warning);
     nl_indent(st);
     st << "end";
   }
@@ -429,14 +450,19 @@ ParameterSetCanvas * ParameterSetCanvas::read(char * & st, UmlCanvas * canvas,
     else
       wrong_keyword(k, "xyz");
 
-  // note :width_scale100 & height_scale100 useless, position depend on pins
+    // note : width_scale100 & height_scale100 useless, position depend on pins
     result->update();
     result->show();
 
-    k = read_keyword(st);    
+    k = read_keyword(st);   
+    
+    result->read_stereotype_property(st, k);	// updates k
+    
     if (strcmp(k, "end"))
       wrong_keyword(k, "end");
 
+    result->check_stereotypeproperties();
+    
     return result;
   }
   else 
