@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qpainter.h>
 #include <qcursor.h>
@@ -88,16 +88,16 @@ void SdLifeLineCanvas::change_scale() {
 }
 
 void SdLifeLineCanvas::drawShape(QPainter & p) {
-  p.setBackgroundMode(QObject::OpaqueMode);
+  p.setBackgroundMode(::Qt::OpaqueMode);
   
-  p.setPen(QObject::DashLine);
+  p.setPen(::Qt::DashLine);
   
   int m = (int) (x()+width()/2);
   FILE * fp = svg();
 
   p.drawLine(m, (int) y(), m, end);
 
-  p.setPen(QObject::SolidLine);
+  p.setPen(::Qt::SolidLine);
 
   if (end != LIFE_LINE_HEIGHT) {
     int b = end + (int) width();
@@ -278,6 +278,8 @@ void SdLifeLineCanvas::menu(const QPoint&) {
   m.insertSeparator();
   m.insertItem("Upper", 0);
   m.insertItem("Lower", 1);
+  m.insertItem("Go up", 2);
+  m.insertItem("Go down", 3);
 
   int index = m.exec(QCursor::pos());
   
@@ -288,6 +290,12 @@ void SdLifeLineCanvas::menu(const QPoint&) {
   case 1:
     lower();
     break;
+  case 2:
+    z_up();
+    break;
+  case 3:
+    z_down();
+    break;
   default:
     return;
   }
