@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -27,11 +27,26 @@
 #define UCCLASSCANVAS_H
 
 #include "DiagramCanvas.h"
+#include "Settings.h"
 
 #define ACTOR_CANVAS_SIZE 40
 
+class TemplateCanvas;
+
 class UcClassCanvas : public QObject, public DiagramCanvas {
   Q_OBJECT
+
+  protected:
+    TemplateCanvas * templ;
+    UmlColor itscolor;
+    UmlColor used_color;
+    SimpleClassDiagramSettings settings;
+    SimpleClassDiagramSettings used_settings;
+    ClassDrawingMode used_view_mode;
+    QString full_name;
+
+  protected:
+    UcClassCanvas(UmlCanvas * canvas, int id);
     
   public:
     UcClassCanvas(BrowserNode * bn, UmlCanvas * canvas, int x, int y, int id);
@@ -40,7 +55,9 @@ class UcClassCanvas : public QObject, public DiagramCanvas {
     virtual void delete_it();
 
     virtual void draw(QPainter & p);
+    virtual void change_scale();
     
+    void compute_size();
     virtual UmlCode type() const;
     virtual void delete_available(bool & in_model, bool & out_model) const;
     virtual bool alignable() const;
@@ -54,6 +71,14 @@ class UcClassCanvas : public QObject, public DiagramCanvas {
     virtual bool has_relation(BasicData *) const; 
     void draw_all_depend_gene(UcClassCanvas * end = 0);
     virtual bool move_with_its_package() const;
+    virtual void moveBy(double dx, double dy);
+    virtual void set_z(double z);	// only called by upper() & lower()
+
+    virtual bool has_drawing_settings() const;
+    virtual void edit_drawing_settings(QList<DiagramItem> &);
+    void edit_drawing_settings();
+    virtual bool get_show_stereotype_properties() const;
+    
     virtual void apply_shortcut(QString s);
     
     virtual void history_load(QBuffer &);
