@@ -966,28 +966,30 @@ void UmlWindow::closeEvent(QCloseEvent * e) {
 
 void UmlWindow::close_it()
 {
-  clear_select_historic();
+  if (user_id() != 0) {
+    clear_select_historic();
+    
+    ToolCom::close_all();
+    
+    the->save_session();
+    
+    QApplication::setOverrideCursor(::Qt::waitCursor);
+    
+    // close all diagram windows
+    // do not hide ws, else a future diagram window opening will crash !
+    the->clear();
+    
+    // empty the browser
+    set_commented(0);
+    the->browser->clear();
+    
+    // remove tools
+    the->toolMenu->clear();
+    
+    QApplication::restoreOverrideCursor();
+    the->setCaption("Bouml");
+  }
   
-  ToolCom::close_all();
-  
-  the->save_session();
-  
-  QApplication::setOverrideCursor(::Qt::waitCursor);
-  
-  // close all diagram windows
-  // do not hide ws, else a future diagram window opening will crash !
-  the->clear();
-  
-  // empty the browser
-  set_commented(0);
-  the->browser->clear();
-  
-  // remove tools
-  the->toolMenu->clear();
-  
-  QApplication::restoreOverrideCursor();
-  the->setCaption("Bouml");
-
   Tool::init();
   GenerationSettings::init();
   BrowserPackage::init();
