@@ -303,7 +303,7 @@ ClassDialog::ClassDialog(ClassData * c)
     cpp_external_cb->setDisabled(TRUE);
   else
     connect(cpp_external_cb, SIGNAL(toggled(bool)),
-	    SLOT(cpp_update_decl()));
+	    SLOT(cpp_default_decl()));
   
   if (bn->nestedp()) {
     bgv = cpp_visibility.init(htab, cl->get_cpp_visibility(),
@@ -381,7 +381,7 @@ ClassDialog::ClassDialog(ClassData * c)
     connect(java_final_cb, SIGNAL(toggled(bool)),
 	    SLOT(java_update_decl()));
     connect(java_external_cb, SIGNAL(toggled(bool)),
-	    SLOT(java_update_decl()));
+	    SLOT(java_default_decl()));
   }
   
   htab = new QHBox(vtab); 
@@ -454,7 +454,7 @@ ClassDialog::ClassDialog(ClassData * c)
     connect(php_final_cb, SIGNAL(toggled(bool)),
 	    SLOT(php_update_decl()));
     connect(php_external_cb, SIGNAL(toggled(bool)),
-	    SLOT(php_update_decl()));
+	    SLOT(php_default_decl()));
   }
   
   htab = new QHBox(vtab); 
@@ -521,7 +521,7 @@ ClassDialog::ClassDialog(ClassData * c)
     connect(python_2_2_cb, SIGNAL(toggled(bool)),
 	    SLOT(python_update_decl()));
     connect(python_external_cb, SIGNAL(toggled(bool)),
-	    SLOT(python_update_decl()));
+	    SLOT(python_default_decl()));
   }
   
   htab = new QHBox(vtab); 
@@ -618,7 +618,7 @@ ClassDialog::ClassDialog(ClassData * c)
     connect(idl_custom_cb, SIGNAL(toggled(bool)),
 	    SLOT(idl_update_decl()));
     connect(idl_external_cb, SIGNAL(toggled(bool)),
-	    SLOT(idl_update_decl()));
+	    SLOT(idl_default_decl()));
   }
   
   htab = new QHBox(vtab); 
@@ -1565,7 +1565,8 @@ void ClassDialog::java_generate_decl(QString & s, ClassData * cl, QString def,
     }
     else if (!strncmp(p, "${visibility}", 13)) {
       p += 13;
-      s += stringify(visibility) + QString(" ");
+      if (visibility != UmlPackageVisibility)
+	s += stringify(visibility) + QString(" ");
     }
     else if (!strncmp(p, "${final}", 8)) {
       p += 8;
