@@ -1,6 +1,6 @@
 // *************************************************************************
 //
-// Copyleft 2004-2007 Bruno PAGES  .
+// Copyleft 2004-2008 Bruno PAGES  .
 //
 // This file is part of the BOUML Uml Toolkit.
 //
@@ -23,9 +23,9 @@
 //
 // *************************************************************************
 
-#ifdef WIN32
-#pragma warning (disable: 4150)
-#endif
+
+
+
 
 #include <qdialog.h>
 #include <qlayout.h>
@@ -37,9 +37,9 @@
 
 void CodEditMsgDialog::exec(ColDiagramView * view, ColMsgList & msgs)
 {
-  QDialog d(0, "Collaboration diagram message dialog", TRUE, 0);
+  QDialog d(0, "Communication diagram message dialog", TRUE, 0);
   
-  d.setCaption("Collaboration diagram message dialog");
+  d.setCaption("Communication diagram message dialog");
   
   QVBoxLayout vbox(&d);
   
