@@ -526,7 +526,7 @@ void GenerationSettingsDialog::init_java1() {
   vtab->setMargin(3);
   htab2->setMargin(3);
 
-  new QLabel("    generated / reversed \n    file extension : ", htab2);
+  new QLabel("    generated/reversed file extension ", htab2);
   edjava_extension = new QComboBox(TRUE, htab2);
   edjava_extension->insertItem(GenerationSettings::java_extension);
   edjava_extension->setCurrentItem(0);
@@ -534,9 +534,15 @@ void GenerationSettingsDialog::init_java1() {
 
   htab2 = new QHBox(vtab);
   htab2->setMargin(3);
-  new QLabel("    generate Javadoc \n    style comment : ", htab2);
+  new QLabel("    generate Javadoc style comment ", htab2);
   java_javadoc_cb = new QCheckBox(htab2);
   java_javadoc_cb->setChecked(GenerationSettings::java_javadoc_comment);
+
+  htab2 = new QHBox(vtab);
+  htab2->setMargin(3);
+  new QLabel("    force package prefix generation ", htab2);
+  java_force_package_gen_cb = new QCheckBox(htab2);
+  java_force_package_gen_cb->setChecked(GenerationSettings::java_force_package_gen);
   
   new QLabel("Class default \ndeclaration :", grid);
   edjava_class_decl = new MultiLineEdit(grid);
@@ -1813,6 +1819,7 @@ void GenerationSettingsDialog::accept() {
       GenerationSettings::java_attr_decl[i] = edjava_attr_decl[i]->text();
     GenerationSettings::java_oper_def = edjava_oper_def->text();
     GenerationSettings::java_javadoc_comment = java_javadoc_cb->isChecked();
+    GenerationSettings::java_force_package_gen = java_force_package_gen_cb->isChecked();
     
     GenerationSettings::php_class_decl = edphp_class_decl->text();
     GenerationSettings::php_external_class_decl = edphp_external_class_decl->text();
